
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RollerCoaster(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-roller-coaster'], 'items': [{'path': {'d': 'M6 19V5'}}, {'path': {'d': 'M10 19V6.8'}}, {'path': {'d': 'M14 19v-7.8'}}, {'path': {'d': 'M18 5v4'}}, {'path': {'d': 'M18 19v-6'}}, {'path': {'d': 'M22 19V9'}}, {'path': {'d': 'M2 19V9a4 4 0 0 1 4-4c2 0 4 1.33 6 4s4 4 6 4a4 4 0 1 0-3-6.65'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Percent(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-percent'], 'items': [{'line': {'x1': '19', 'x2': '5', 'y1': '5', 'y2': '19'}}, {'circle': {'cx': '6.5', 'cy': '6.5', 'r': '2.5'}}, {'circle': {'cx': '17.5', 'cy': '17.5', 'r': '2.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lollipop(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lollipop'], 'items': [{'circle': {'cx': '11', 'cy': '11', 'r': '8'}}, {'path': {'d': 'm21 21-4.3-4.3'}}, {'path': {'d': 'M11 11a2 2 0 0 0 4 0 4 4 0 0 0-8 0 6 6 0 0 0 12 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wallpaper(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wallpaper'], 'items': [{'path': {'d': 'M12 17v4'}}, {'path': {'d': 'M8 21h8'}}, {'path': {'d': 'm9 17 6.1-6.1a2 2 0 0 1 2.81.01L22 15'}}, {'circle': {'cx': '8', 'cy': '9', 'r': '2'}}, {'rect': {'x': '2', 'y': '3', 'width': '20', 'height': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Aperture(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-aperture'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'm14.31 8 5.74 9.94'}}, {'path': {'d': 'M9.69 8h11.48'}}, {'path': {'d': 'm7.38 12 5.74-9.94'}}, {'path': {'d': 'M9.69 16 3.95 6.06'}}, {'path': {'d': 'M14.31 16H2.83'}}, {'path': {'d': 'm16.62 12-5.74 9.94'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def VenusAndMars(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-venus-and-mars'], 'items': [{'path': {'d': 'M10 20h4'}}, {'path': {'d': 'M12 16v6'}}, {'path': {'d': 'M17 2h4v4'}}, {'path': {'d': 'm21 2-5.46 5.46'}}, {'circle': {'cx': '12', 'cy': '11', 'r': '5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BanknoteArrowDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-banknote-arrow-down'], 'items': [{'path': {'d': 'M12 18H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5'}}, {'path': {'d': 'm16 19 3 3 3-3'}}, {'path': {'d': 'M18 12h.01'}}, {'path': {'d': 'M19 16v6'}}, {'path': {'d': 'M6 12h.01'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleGauge(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-gauge'], 'items': [{'path': {'d': 'M15.6 2.7a10 10 0 1 0 5.7 5.7'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '2'}}, {'path': {'d': 'M13.4 10.6 19 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BaggageClaim(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-baggage-claim'], 'items': [{'path': {'d': 'M22 18H6a2 2 0 0 1-2-2V7a2 2 0 0 0-2-2'}}, {'path': {'d': 'M17 14V4a2 2 0 0 0-2-2h-1a2 2 0 0 0-2 2v10'}}, {'rect': {'width': '13', 'height': '8', 'x': '8', 'y': '6', 'rx': '1'}}, {'circle': {'cx': '18', 'cy': '20', 'r': '2'}}, {'circle': {'cx': '9', 'cy': '20', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Eraser(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-eraser'], 'items': [{'path': {'d': 'M21 21H8a2 2 0 0 1-1.42-.587l-3.994-3.999a2 2 0 0 1 0-2.828l10-10a2 2 0 0 1 2.829 0l5.999 6a2 2 0 0 1 0 2.828L12.834 21'}}, {'path': {'d': 'm5.082 11.09 8.828 8.828'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Shrub(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shrub'], 'items': [{'path': {'d': 'M12 22v-5.172a2 2 0 0 0-.586-1.414L9.5 13.5'}}, {'path': {'d': 'M14.5 14.5 12 17'}}, {'path': {'d': 'M17 8.8A6 6 0 0 1 13.8 20H10A6.5 6.5 0 0 1 7 8a5 5 0 0 1 10 0z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pocket(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pocket'], 'items': [{'path': {'d': 'M20 3a2 2 0 0 1 2 2v6a1 1 0 0 1-20 0V5a2 2 0 0 1 2-2z'}}, {'path': {'d': 'm8 10 4 4 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Cast(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cast'], 'items': [{'path': {'d': 'M2 8V6a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2h-6'}}, {'path': {'d': 'M2 12a9 9 0 0 1 8 8'}}, {'path': {'d': 'M2 16a5 5 0 0 1 4 4'}}, {'line': {'x1': '2', 'x2': '2.01', 'y1': '20', 'y2': '20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ThumbsUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-thumbs-up'], 'items': [{'path': {'d': 'M7 10v12'}}, {'path': {'d': 'M15 5.88 14 10h5.83a2 2 0 0 1 1.92 2.56l-2.33 8A2 2 0 0 1 17.5 22H4a2 2 0 0 1-2-2v-8a2 2 0 0 1 2-2h2.76a2 2 0 0 0 1.79-1.11L12 2a3.13 3.13 0 0 1 3 3.88Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListFilterPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-filter-plus'], 'items': [{'path': {'d': 'M12 5H2'}}, {'path': {'d': 'M6 12h12'}}, {'path': {'d': 'M9 19h6'}}, {'path': {'d': 'M16 5h6'}}, {'path': {'d': 'M19 8V2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Move3d(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-3d'], 'items': [{'path': {'d': 'M5 3v16h16'}}, {'path': {'d': 'm5 19 6-6'}}, {'path': {'d': 'm2 6 3-3 3 3'}}, {'path': {'d': 'm18 16 3 3-3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-left'], 'items': [{'path': {'d': 'M6 8L2 12L6 16'}}, {'path': {'d': 'M2 12H22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hash'], 'items': [{'line': {'x1': '4', 'x2': '20', 'y1': '9', 'y2': '9'}}, {'line': {'x1': '4', 'x2': '20', 'y1': '15', 'y2': '15'}}, {'line': {'x1': '10', 'x2': '8', 'y1': '3', 'y2': '21'}}, {'line': {'x1': '16', 'x2': '14', 'y1': '3', 'y2': '21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Landmark(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-landmark'], 'items': [{'path': {'d': 'M10 18v-7'}}, {'path': {'d': 'M11.12 2.198a2 2 0 0 1 1.76.006l7.866 3.847c.476.233.31.949-.22.949H3.474c-.53 0-.695-.716-.22-.949z'}}, {'path': {'d': 'M14 18v-7'}}, {'path': {'d': 'M18 18v-7'}}, {'path': {'d': 'M3 22h18'}}, {'path': {'d': 'M6 18v-7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Anchor(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-anchor'], 'items': [{'path': {'d': 'M12 6v16'}}, {'path': {'d': 'm19 13 2-1a9 9 0 0 1-18 0l2 1'}}, {'path': {'d': 'M9 11h6'}}, {'circle': {'cx': '12', 'cy': '4', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Layers2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-layers-2'], 'items': [{'path': {'d': 'M13 13.74a2 2 0 0 1-2 0L2.5 8.87a1 1 0 0 1 0-1.74L11 2.26a2 2 0 0 1 2 0l8.5 4.87a1 1 0 0 1 0 1.74z'}}, {'path': {'d': 'm20 14.285 1.5.845a1 1 0 0 1 0 1.74L13 21.74a2 2 0 0 1-2 0l-8.5-4.87a1 1 0 0 1 0-1.74l1.5-.845'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderOpenDot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-open-dot'], 'items': [{'path': {'d': 'm6 14 1.45-2.9A2 2 0 0 1 9.24 10H20a2 2 0 0 1 1.94 2.5l-1.55 6a2 2 0 0 1-1.94 1.5H4a2 2 0 0 1-2-2V5c0-1.1.9-2 2-2h3.93a2 2 0 0 1 1.66.9l.82 1.2a2 2 0 0 0 1.66.9H18a2 2 0 0 1 2 2v2'}}, {'circle': {'cx': '14', 'cy': '15', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ScreenShare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-screen-share'], 'items': [{'path': {'d': 'M13 3H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-3'}}, {'path': {'d': 'M8 21h8'}}, {'path': {'d': 'M12 17v4'}}, {'path': {'d': 'm17 8 5-5'}}, {'path': {'d': 'M17 3h5v5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClockArrowUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clock-arrow-up'], 'items': [{'path': {'d': 'M12 6v6l1.56.78'}}, {'path': {'d': 'M13.227 21.925a10 10 0 1 1 8.767-9.588'}}, {'path': {'d': 'm14 18 4-4 4 4'}}, {'path': {'d': 'M18 22v-8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Form(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-form'], 'items': [{'path': {'d': 'M4 14h6'}}, {'path': {'d': 'M4 2h10'}}, {'rect': {'x': '4', 'y': '18', 'width': '16', 'height': '4', 'rx': '1'}}, {'rect': {'x': '4', 'y': '6', 'width': '16', 'height': '4', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Snail(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-snail'], 'items': [{'path': {'d': 'M2 13a6 6 0 1 0 12 0 4 4 0 1 0-8 0 2 2 0 0 0 4 0'}}, {'circle': {'cx': '10', 'cy': '13', 'r': '8'}}, {'path': {'d': 'M2 21h12c4.4 0 8-3.6 8-8V7a2 2 0 1 0-4 0v6'}}, {'path': {'d': 'M18 3 19.1 5.2'}}, {'path': {'d': 'M22 3 20.9 5.2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CodeXml(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-code-xml'], 'items': [{'path': {'d': 'm18 16 4-4-4-4'}}, {'path': {'d': 'm6 8-4 4 4 4'}}, {'path': {'d': 'm14.5 4-5 16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield



import os
import json
import keyword
from fastapi import FastAPI
from fastapi.responses import HTMLResponse
from tagflow import document, tag, text
from collections import defaultdict
import importlib

# Helper function from test_all_icons
def to_pascal_case(s):
    pascal_cased = ''.join(word.capitalize() for word in s.replace('-', '_').split('_'))
    if keyword.iskeyword(pascal_cased):
        return pascal_cased + '_'
    return pascal_cased

app = FastAPI()

def get_categorized_icons():
    icons_dir = 'resources/lucide/icons'
    categorized_icons = defaultdict(list)
    icon_details = {} # Store icon details including categories
    
    for filename in os.listdir(icons_dir):
        if not filename.endswith('.json'):
            continue
            
        icon_name = os.path.splitext(filename)[0]
        
        with open(os.path.join(icons_dir, filename), 'r') as f:
            try:
                data = json.load(f)
                categories = data.get('categories', [])
                icon_details[icon_name] = categories # Store categories for each icon
                for category in categories:
                    categorized_icons[category].append(icon_name)
            except json.JSONDecodeError:
                print(f"Could not decode JSON for {icon_name}")
                continue
                
    return categorized_icons, icon_details

@app.get("/", response_class=HTMLResponse)
async def read_root():
    categorized_icons, icon_details = get_categorized_icons()
    
    with document() as doc:
        with tag("html", class_="bg-gray-100 text-gray-800"):
            with tag("head"):
                with tag("title"):
                    text("Lucide Icons")
                tag("script", src="https://cdn.tailwindcss.com")
                with tag("script"):
                    text("""
                        function filterIcons(selectedCategory) {
                            // Deactivate all category buttons
                            document.querySelectorAll('.category-button').forEach(button => {
                                button.classList.remove('bg-blue-500', 'text-white');
                                button.classList.add('bg-gray-200', 'text-gray-700');
                            });

                            // Activate the selected category button
                            const activeButton = document.getElementById('btn-' + selectedCategory);
                            if (activeButton) {
                                activeButton.classList.add('bg-blue-500', 'text-white');
                                activeButton.classList.remove('bg-gray-200', 'text-gray-700');
                            }

                            document.querySelectorAll('.icon-card').forEach(card => {
                                const categories = card.dataset.categories ? card.dataset.categories.split(',') : [];
                                if (selectedCategory === 'all' || categories.includes(selectedCategory)) {
                                    card.style.display = 'flex';
                                } else {
                                    card.style.display = 'none';
                                }
                            });
                        }

                        function searchIcons() {
                            const query = document.getElementById('search-box').value.toLowerCase();
                            document.querySelectorAll('.icon-card').forEach(card => {
                                const iconName = card.dataset.iconName.toLowerCase();
                                // Only filter visible icons (those not hidden by category filter)
                                if (card.style.display !== 'none') {
                                    if (iconName.includes(query)) {
                                        card.style.display = 'flex';
                                    } else {
                                        card.style.display = 'none';
                                    }
                                }
                            });
                        }

                        // Initial filter to show all icons when page loads
                        document.addEventListener('DOMContentLoaded', () => {
                            filterIcons('all');
                        });
                    """)
            with tag("body", class_="p-8"):
                with tag("div", class_="flex justify-between items-center mb-8"):
                    with tag("h1", class_="text-4xl font-bold"):
                        text("Lucide Icons")
                    with tag("input", id="search-box", type="text", placeholder="Search icons...", class_="px-4 py-2 border rounded-lg", onkeyup="searchIcons()"):
                        pass

                with tag("div", class_="flex flex-wrap gap-2 border-b pb-4 mb-8"): # Changed to flex-wrap for buttons
                    with tag("button", id="btn-all", class_="category-button py-2 px-4 bg-blue-500 text-white rounded-lg focus:outline-none", onclick="filterIcons('all')"):
                        text("All")
                    for category in sorted(categorized_icons.keys()):
                        with tag("button", id=f"btn-{category}", class_="category-button py-2 px-4 bg-gray-200 text-gray-700 rounded-lg focus:outline-none", onclick=f"filterIcons('{category}')"):
                            text(category.capitalize())

                with tag("div", id="all-icons-container", class_="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-6 xl:grid-cols-8 gap-4"):
                    # Iterate through all icons, not just categorized ones, to ensure all are displayed
                    # and then filtered by category.
                    all_icon_names = sorted(icon_details.keys())
                    for icon_name in all_icon_names:
                        module_name = icon_name.replace('-', '_')
                        if keyword.iskeyword(module_name):
                            module_name += '_'
                        class_name = to_pascal_case(icon_name)
                        
                        # Get categories for the current icon
                        icon_categories = icon_details.get(icon_name, [])
                        data_categories_attr = ','.join(icon_categories)

                        with tag("div", class_="icon-card flex flex-col items-center justify-center p-4 border rounded-lg shadow-sm bg-white", **{'data-icon-name': icon_name, 'data-categories': data_categories_attr}):
                            try:
                                module = importlib.import_module(f'lucide.icons.{module_name}')
                                icon_class = getattr(module, class_name)
                                with tag("div"):
                                    with icon_class(width="64", height="64"):
                                        pass                                
                                    with tag("p", class_="text-sm mt-2"):
                                      text(icon_name)
                            except (ImportError, AttributeError):
                                with tag("div", class_="text-red-500"):
                                    text(f"Error: {icon_name}")

    return doc.to_html()

if __name__ == "__main__":
    import uvicorn
    uvicorn.run(app, host="0.0.0.0", port=8000)




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ToyBrick(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-toy-brick'], 'items': [{'rect': {'width': '18', 'height': '12', 'x': '3', 'y': '8', 'rx': '1'}}, {'path': {'d': 'M10 8V5c0-.6-.4-1-1-1H6a1 1 0 0 0-1 1v3'}}, {'path': {'d': 'M19 8V5c0-.6-.4-1-1-1h-3a1 1 0 0 0-1 1v3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Mic(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mic'], 'items': [{'path': {'d': 'M12 19v3'}}, {'path': {'d': 'M19 10v2a7 7 0 0 1-14 0v-2'}}, {'rect': {'x': '9', 'y': '2', 'width': '6', 'height': '13', 'rx': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Codepen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-codepen'], 'items': [{'polygon': {'points': '12 2 22 8.5 22 15.5 12 22 2 15.5 2 8.5 12 2'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '22', 'y2': '15.5'}}, {'polyline': {'points': '22 8.5 12 15.5 2 8.5'}}, {'polyline': {'points': '2 15.5 12 8.5 22 15.5'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '2', 'y2': '8.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Stethoscope(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-stethoscope'], 'items': [{'path': {'d': 'M11 2v2'}}, {'path': {'d': 'M5 2v2'}}, {'path': {'d': 'M5 3H4a2 2 0 0 0-2 2v4a6 6 0 0 0 12 0V5a2 2 0 0 0-2-2h-1'}}, {'path': {'d': 'M8 15a6 6 0 0 0 12 0v-3'}}, {'circle': {'cx': '20', 'cy': '10', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Scan(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scan'], 'items': [{'path': {'d': 'M3 7V5a2 2 0 0 1 2-2h2'}}, {'path': {'d': 'M17 3h2a2 2 0 0 1 2 2v2'}}, {'path': {'d': 'M21 17v2a2 2 0 0 1-2 2h-2'}}, {'path': {'d': 'M7 21H5a2 2 0 0 1-2-2v-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Crop(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-crop'], 'items': [{'path': {'d': 'M6 2v14a2 2 0 0 0 2 2h14'}}, {'path': {'d': 'M18 22V8a2 2 0 0 0-2-2H2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowDownNarrowWide(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-down-narrow-wide'], 'items': [{'path': {'d': 'm3 16 4 4 4-4'}}, {'path': {'d': 'M7 20V4'}}, {'path': {'d': 'M11 4h4'}}, {'path': {'d': 'M11 8h7'}}, {'path': {'d': 'M11 12h10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookSearch(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-search'], 'items': [{'path': {'d': 'M11 22H5.5a1 1 0 0 1 0-5h4.501'}}, {'path': {'d': 'm21 22-1.879-1.878'}}, {'path': {'d': 'M3 19.5v-15A2.5 2.5 0 0 1 5.5 2H18a1 1 0 0 1 1 1v8'}}, {'circle': {'cx': '17', 'cy': '18', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Donut(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-donut'], 'items': [{'path': {'d': 'M20.5 10a2.5 2.5 0 0 1-2.4-3H18a2.95 2.95 0 0 1-2.6-4.4 10 10 0 1 0 6.3 7.1c-.3.2-.8.3-1.2.3'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SprayCan(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-spray-can'], 'items': [{'path': {'d': 'M3 3h.01'}}, {'path': {'d': 'M7 5h.01'}}, {'path': {'d': 'M11 7h.01'}}, {'path': {'d': 'M3 7h.01'}}, {'path': {'d': 'M7 9h.01'}}, {'path': {'d': 'M3 11h.01'}}, {'rect': {'width': '4', 'height': '4', 'x': '15', 'y': '5'}}, {'path': {'d': 'm19 9 2 2v10c0 .6-.4 1-1 1h-6c-.6 0-1-.4-1-1V11l2-2'}}, {'path': {'d': 'm13 14 8-2'}}, {'path': {'d': 'm13 19 8-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Computer(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-computer'], 'items': [{'rect': {'width': '14', 'height': '8', 'x': '5', 'y': '2', 'rx': '2'}}, {'rect': {'width': '20', 'height': '8', 'x': '2', 'y': '14', 'rx': '2'}}, {'path': {'d': 'M6 18h2'}}, {'path': {'d': 'M12 18h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Blocks(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-blocks'], 'items': [{'path': {'d': 'M10 22V7a1 1 0 0 0-1-1H4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-5a1 1 0 0 0-1-1H2'}}, {'rect': {'x': '14', 'y': '2', 'width': '8', 'height': '8', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Ghost(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ghost'], 'items': [{'path': {'d': 'M9 10h.01'}}, {'path': {'d': 'M15 10h.01'}}, {'path': {'d': 'M12 2a8 8 0 0 0-8 8v12l3-3 2.5 2.5L12 19l2.5 2.5L17 19l3 3V10a8 8 0 0 0-8-8z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Timer(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-timer'], 'items': [{'line': {'x1': '10', 'x2': '14', 'y1': '2', 'y2': '2'}}, {'line': {'x1': '12', 'x2': '15', 'y1': '14', 'y2': '11'}}, {'circle': {'cx': '12', 'cy': '14', 'r': '8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RotateCw(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rotate-cw'], 'items': [{'path': {'d': 'M21 12a9 9 0 1 1-9-9c2.52 0 4.93 1 6.74 2.74L21 8'}}, {'path': {'d': 'M21 3v5h-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator
from tagflow import tag
from tagflow.tagflow import AttrValue


@contextlib.contextmanager
def IconBase(
    data: dict, **kwargs
) -> Generator[None]:
    defaults = {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round",
    }
    if "classes" in data:
        defaults["classes"] = data.get("classes")
    
    defaults.update(kwargs)

    with tag.svg(**defaults):        
        for item in data["items"]:
            for element_name, element_attrs in item.items():
                with tag(element_name, **element_attrs):
                    pass
    
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Utensils(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-utensils'], 'items': [{'path': {'d': 'M3 2v7c0 1.1.9 2 2 2h4a2 2 0 0 0 2-2V2'}}, {'path': {'d': 'M7 2v20'}}, {'path': {'d': 'M21 15V2a5 5 0 0 0-5 5v6c0 1.1.9 2 2 2h3Zm0 0v7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Keyboard(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-keyboard'], 'items': [{'path': {'d': 'M10 8h.01'}}, {'path': {'d': 'M12 12h.01'}}, {'path': {'d': 'M14 8h.01'}}, {'path': {'d': 'M16 12h.01'}}, {'path': {'d': 'M18 8h.01'}}, {'path': {'d': 'M6 8h.01'}}, {'path': {'d': 'M7 16h10'}}, {'path': {'d': 'M8 12h.01'}}, {'rect': {'width': '20', 'height': '16', 'x': '2', 'y': '4', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowDown10(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-down-1-0'], 'items': [{'path': {'d': 'm3 16 4 4 4-4'}}, {'path': {'d': 'M7 20V4'}}, {'path': {'d': 'M17 10V4h-2'}}, {'path': {'d': 'M15 10h4'}}, {'rect': {'x': '15', 'y': '14', 'width': '4', 'height': '6', 'ry': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ShoppingBag(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shopping-bag'], 'items': [{'path': {'d': 'M16 10a4 4 0 0 1-8 0'}}, {'path': {'d': 'M3.103 6.034h17.794'}}, {'path': {'d': 'M3.4 5.467a2 2 0 0 0-.4 1.2V20a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V6.667a2 2 0 0 0-.4-1.2l-2-2.667A2 2 0 0 0 17 2H7a2 2 0 0 0-1.6.8z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BottleWine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bottle-wine'], 'items': [{'path': {'d': 'M10 3a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v2a6 6 0 0 0 1.2 3.6l.6.8A6 6 0 0 1 17 13v8a1 1 0 0 1-1 1H8a1 1 0 0 1-1-1v-8a6 6 0 0 1 1.2-3.6l.6-.8A6 6 0 0 0 10 5z'}}, {'path': {'d': 'M17 13h-4a1 1 0 0 0-1 1v3a1 1 0 0 0 1 1h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield



import pytest
from tagflow import (    
    tag,
    text,
    document
)

@pytest.fixture
def doc():
    """Create a new document for testing"""
    with document() as d:
        yield d


def test_basic_document():
    """Test creating a basic document with tags and text"""
    with document() as doc:
        with tag("div"):
            with tag("p"):
                text("Hello World")

    result = doc.to_html(compact=True)
    assert "<div><p>Hello World</p></div>" in result


import os
import importlib
import xml.etree.ElementTree as ET
import keyword
import pytest
from tagflow import (    
    tag,
    html,
    text,
    document
)


@pytest.fixture
def doc():
    """Create a new document for testing"""
    with document() as d:
        yield d


def test_basic_document():
    """Test creating a basic document with tags and text"""
    with document() as doc:
        with tag("div"):
            with tag("p"):
                text("Hello World")

    result = doc.to_html(compact=True)
    assert "<div><p>Hello World</p></div>" in result


def to_pascal_case(s):
    pascal_cased = ''.join(word.capitalize() for word in s.replace('-', '_').split('_'))
    if keyword.iskeyword(pascal_cased):
        return pascal_cased + '_'
    return pascal_cased

def test_all_icons():
    icons_dir = 'resources/lucide/icons'
    for filename in os.listdir(icons_dir):
        if not filename.endswith('.svg'):
            continue

        icon_name = os.path.splitext(filename)[0]
        module_name = icon_name.replace('-', '_')
        if keyword.iskeyword(module_name):
            module_name += '_'
        
        class_name = to_pascal_case(icon_name)

        print(f"Testing {class_name}")

        try:
            module = importlib.import_module(f'lucide.icons.{module_name}')
            icon_class = getattr(module, class_name)
        except (ImportError, AttributeError):
            pytest.fail(f"Could not import {class_name} from lucide.icons.{module_name}")

        with document() as doc:
            with icon_class():
                pass
            rendered_svg_string = doc.to_html(compact=True)
        
        with open(os.path.join(icons_dir, filename), 'r') as f:
            original_svg_string = f.read()

        rendered_root = ET.fromstring(rendered_svg_string)
        original_root = ET.fromstring(original_svg_string)

        rendered_children = list(rendered_root)
        original_children = list(original_root)

        assert len(rendered_children) == len(original_children)

        for rendered_child, original_child in zip(rendered_children, original_children):
            # Compare tags (ignoring namespace)
            assert rendered_child.tag.split('}')[-1] == original_child.tag.split('}')[-1]
            # Compare attributes
            assert rendered_child.attrib == original_child.attrib








import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChevronLast(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chevron-last'], 'items': [{'path': {'d': 'm7 18 6-6-6-6'}}, {'path': {'d': 'M17 6v12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartCandlestick(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-candlestick'], 'items': [{'path': {'d': 'M9 5v4'}}, {'rect': {'width': '4', 'height': '6', 'x': '7', 'y': '9', 'rx': '1'}}, {'path': {'d': 'M9 15v2'}}, {'path': {'d': 'M17 3v2'}}, {'rect': {'width': '4', 'height': '8', 'x': '15', 'y': '5', 'rx': '1'}}, {'path': {'d': 'M17 13v3'}}, {'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SignpostBig(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-signpost-big'], 'items': [{'path': {'d': 'M10 9H4L2 7l2-2h6'}}, {'path': {'d': 'M14 5h6l2 2-2 2h-6'}}, {'path': {'d': 'M10 22V4a2 2 0 1 1 4 0v18'}}, {'path': {'d': 'M8 22h8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlignVerticalDistributeCenter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-align-vertical-distribute-center'], 'items': [{'path': {'d': 'M22 17h-3'}}, {'path': {'d': 'M22 7h-5'}}, {'path': {'d': 'M5 17H2'}}, {'path': {'d': 'M7 7H2'}}, {'rect': {'x': '5', 'y': '14', 'width': '14', 'height': '6', 'rx': '2'}}, {'rect': {'x': '7', 'y': '4', 'width': '10', 'height': '6', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Blinds(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-blinds'], 'items': [{'path': {'d': 'M3 3h18'}}, {'path': {'d': 'M20 7H8'}}, {'path': {'d': 'M20 11H8'}}, {'path': {'d': 'M10 19h10'}}, {'path': {'d': 'M8 15h12'}}, {'path': {'d': 'M4 3v14'}}, {'circle': {'cx': '4', 'cy': '19', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SendHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-send-horizontal'], 'items': [{'path': {'d': 'M3.714 3.048a.498.498 0 0 0-.683.627l2.843 7.627a2 2 0 0 1 0 1.396l-2.842 7.627a.498.498 0 0 0 .682.627l18-8.5a.5.5 0 0 0 0-.904z'}}, {'path': {'d': 'M6 12h16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lasso(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lasso'], 'items': [{'path': {'d': 'M3.704 14.467A10 8 0 0 1 2 10a10 8 0 0 1 20 0 10 8 0 0 1-10 8 10 8 0 0 1-5.181-1.158'}}, {'path': {'d': 'M7 22a5 5 0 0 1-2-3.994'}}, {'circle': {'cx': '5', 'cy': '16', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlagTriangleRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flag-triangle-right'], 'items': [{'path': {'d': 'M6 22V2.8a.8.8 0 0 1 1.17-.71l11.38 5.69a.8.8 0 0 1 0 1.44L6 15.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Key(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-key'], 'items': [{'path': {'d': 'm15.5 7.5 2.3 2.3a1 1 0 0 0 1.4 0l2.1-2.1a1 1 0 0 0 0-1.4L19 4'}}, {'path': {'d': 'm21 2-9.6 9.6'}}, {'circle': {'cx': '7.5', 'cy': '15.5', 'r': '5.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FerrisWheel(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ferris-wheel'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '2'}}, {'path': {'d': 'M12 2v4'}}, {'path': {'d': 'm6.8 15-3.5 2'}}, {'path': {'d': 'm20.7 7-3.5 2'}}, {'path': {'d': 'M6.8 9 3.3 7'}}, {'path': {'d': 'm20.7 17-3.5-2'}}, {'path': {'d': 'm9 22 3-8 3 8'}}, {'path': {'d': 'M8 22h8'}}, {'path': {'d': 'M18 18.7a9 9 0 1 0-12 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GalleryVerticalEnd(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-gallery-vertical-end'], 'items': [{'path': {'d': 'M7 2h10'}}, {'path': {'d': 'M5 6h14'}}, {'rect': {'width': '18', 'height': '12', 'x': '3', 'y': '10', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleArrowOutDownRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-arrow-out-down-right'], 'items': [{'path': {'d': 'M12 22a10 10 0 1 1 10-10'}}, {'path': {'d': 'M22 22 12 12'}}, {'path': {'d': 'M22 16v6h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ConciergeBell(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-concierge-bell'], 'items': [{'path': {'d': 'M3 20a1 1 0 0 1-1-1v-1a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1Z'}}, {'path': {'d': 'M20 16a8 8 0 1 0-16 0'}}, {'path': {'d': 'M12 4v4'}}, {'path': {'d': 'M10 4h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TreePine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tree-pine'], 'items': [{'path': {'d': 'm17 14 3 3.3a1 1 0 0 1-.7 1.7H4.7a1 1 0 0 1-.7-1.7L7 14h-.3a1 1 0 0 1-.7-1.7L9 9h-.2A1 1 0 0 1 8 7.3L12 3l4 4.3a1 1 0 0 1-.8 1.7H15l3 3.3a1 1 0 0 1-.7 1.7H17Z'}}, {'path': {'d': 'M12 22v-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Axis3d(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-axis-3d'], 'items': [{'path': {'d': 'M13.5 10.5 15 9'}}, {'path': {'d': 'M4 4v15a1 1 0 0 0 1 1h15'}}, {'path': {'d': 'M4.293 19.707 6 18'}}, {'path': {'d': 'm9 15 1.5-1.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Airplay(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-airplay'], 'items': [{'path': {'d': 'M5 17H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-1'}}, {'path': {'d': 'm12 15 5 6H7Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bomb(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bomb'], 'items': [{'circle': {'cx': '11', 'cy': '13', 'r': '9'}}, {'path': {'d': 'M14.35 4.65 16.3 2.7a2.41 2.41 0 0 1 3.4 0l1.6 1.6a2.4 2.4 0 0 1 0 3.4l-1.95 1.95'}}, {'path': {'d': 'm22 2-1.5 1.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Plug(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-plug'], 'items': [{'path': {'d': 'M12 22v-5'}}, {'path': {'d': 'M15 8V2'}}, {'path': {'d': 'M17 8a1 1 0 0 1 1 1v4a4 4 0 0 1-4 4h-4a4 4 0 0 1-4-4V9a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M9 8V2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlignEndHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-align-end-horizontal'], 'items': [{'rect': {'width': '6', 'height': '16', 'x': '4', 'y': '2', 'rx': '2'}}, {'rect': {'width': '6', 'height': '9', 'x': '14', 'y': '9', 'rx': '2'}}, {'path': {'d': 'M22 22H2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookCopy(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-copy'], 'items': [{'path': {'d': 'M5 7a2 2 0 0 0-2 2v11'}}, {'path': {'d': 'M5.803 18H5a2 2 0 0 0 0 4h9.5a.5.5 0 0 0 .5-.5V21'}}, {'path': {'d': 'M9 15V4a2 2 0 0 1 2-2h9.5a.5.5 0 0 1 .5.5v14a.5.5 0 0 1-.5.5H11a2 2 0 0 1 0-4h10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bird(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bird'], 'items': [{'path': {'d': 'M16 7h.01'}}, {'path': {'d': 'M3.4 18H12a8 8 0 0 0 8-8V7a4 4 0 0 0-7.28-2.3L2 20'}}, {'path': {'d': 'm20 7 2 .5-2 .5'}}, {'path': {'d': 'M10 18v3'}}, {'path': {'d': 'M14 17.75V21'}}, {'path': {'d': 'M7 18a6 6 0 0 0 3.84-10.61'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Umbrella(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-umbrella'], 'items': [{'path': {'d': 'M12 13v7a2 2 0 0 0 4 0'}}, {'path': {'d': 'M12 2v2'}}, {'path': {'d': 'M20.992 13a1 1 0 0 0 .97-1.274 10.284 10.284 0 0 0-19.923 0A1 1 0 0 0 3 13z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FireExtinguisher(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-fire-extinguisher'], 'items': [{'path': {'d': 'M15 6.5V3a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v3.5'}}, {'path': {'d': 'M9 18h8'}}, {'path': {'d': 'M18 3h-3'}}, {'path': {'d': 'M11 3a6 6 0 0 0-6 6v11'}}, {'path': {'d': 'M5 13h4'}}, {'path': {'d': 'M17 10a4 4 0 0 0-8 0v10a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RotateCcwSquare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rotate-ccw-square'], 'items': [{'path': {'d': 'M20 9V7a2 2 0 0 0-2-2h-6'}}, {'path': {'d': 'm15 2-3 3 3 3'}}, {'path': {'d': 'M20 13v5a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-off'], 'items': [{'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M5.782 5.782A7 7 0 0 0 9 19h8.5a4.5 4.5 0 0 0 1.307-.193'}}, {'path': {'d': 'M21.532 16.5A4.5 4.5 0 0 0 17.5 10h-1.79A7.008 7.008 0 0 0 10 5.07'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SaveOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-save-off'], 'items': [{'path': {'d': 'M13 13H8a1 1 0 0 0-1 1v7'}}, {'path': {'d': 'M14 8h1'}}, {'path': {'d': 'M17 21v-4'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M20.41 20.41A2 2 0 0 1 19 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 .59-1.41'}}, {'path': {'d': 'M29.5 11.5s5 5 4 5'}}, {'path': {'d': 'M9 3h6.2a2 2 0 0 1 1.4.6l3.8 3.8a2 2 0 0 1 .6 1.4V15'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChessBishop(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chess-bishop'], 'items': [{'path': {'d': 'M5 20a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1z'}}, {'path': {'d': 'M15 18c1.5-.615 3-2.461 3-4.923C18 8.769 14.5 4.462 12 2 9.5 4.462 6 8.77 6 13.077 6 15.539 7.5 17.385 9 18'}}, {'path': {'d': 'm16 7-2.5 2.5'}}, {'path': {'d': 'M9 2h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hamburger(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hamburger'], 'items': [{'path': {'d': 'M12 16H4a2 2 0 1 1 0-4h16a2 2 0 1 1 0 4h-4.25'}}, {'path': {'d': 'M5 12a2 2 0 0 1-2-2 9 7 0 0 1 18 0 2 2 0 0 1-2 2'}}, {'path': {'d': 'M5 16a2 2 0 0 0-2 2 3 3 0 0 0 3 3h12a3 3 0 0 0 3-3 2 2 0 0 0-2-2q0 0 0 0'}}, {'path': {'d': 'm6.67 12 6.13 4.6a2 2 0 0 0 2.8-.4l3.15-4.2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-up'], 'items': [{'path': {'d': 'm5 12 7-7 7 7'}}, {'path': {'d': 'M12 19V5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlipHorizontal2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flip-horizontal-2'], 'items': [{'path': {'d': 'm3 7 5 5-5 5V7'}}, {'path': {'d': 'm21 7-5 5 5 5V7'}}, {'path': {'d': 'M12 20v2'}}, {'path': {'d': 'M12 14v2'}}, {'path': {'d': 'M12 8v2'}}, {'path': {'d': 'M12 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UtensilsCrossed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-utensils-crossed'], 'items': [{'path': {'d': 'm16 2-2.3 2.3a3 3 0 0 0 0 4.2l1.8 1.8a3 3 0 0 0 4.2 0L22 8'}}, {'path': {'d': 'M15 15 3.3 3.3a4.2 4.2 0 0 0 0 6l7.3 7.3c.7.7 2 .7 2.8 0L15 15Zm0 0 7 7'}}, {'path': {'d': 'm2.1 21.8 6.4-6.3'}}, {'path': {'d': 'm19 5-7 7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wine'], 'items': [{'path': {'d': 'M8 22h8'}}, {'path': {'d': 'M7 10h10'}}, {'path': {'d': 'M12 15v7'}}, {'path': {'d': 'M12 15a5 5 0 0 0 5-5c0-2-.5-4-2-8H9c-1.5 4-2 6-2 8a5 5 0 0 0 5 5Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AArrowDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-a-arrow-down'], 'items': [{'path': {'d': 'm14 12 4 4 4-4'}}, {'path': {'d': 'M18 16V7'}}, {'path': {'d': 'm2 16 4.039-9.69a.5.5 0 0 1 .923 0L11 16'}}, {'path': {'d': 'M3.304 13h6.392'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Omega(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-omega'], 'items': [{'path': {'d': 'M3 20h4.5a.5.5 0 0 0 .5-.5v-.282a.52.52 0 0 0-.247-.437 8 8 0 1 1 8.494-.001.52.52 0 0 0-.247.438v.282a.5.5 0 0 0 .5.5H21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowBigDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-big-down'], 'items': [{'path': {'d': 'M15 11a1 1 0 0 0 1 1h2.939a1 1 0 0 1 .75 1.811l-6.835 6.836a1.207 1.207 0 0 1-1.707 0L4.31 13.81a1 1 0 0 1 .75-1.811H8a1 1 0 0 0 1-1V5a1 1 0 0 1 1-1h4a1 1 0 0 1 1 1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SwitchCamera(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-switch-camera'], 'items': [{'path': {'d': 'M11 19H4a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h5'}}, {'path': {'d': 'M13 5h7a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-5'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '3'}}, {'path': {'d': 'm18 22-3-3 3-3'}}, {'path': {'d': 'm6 2 3 3-3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TvMinimalPlay(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tv-minimal-play'], 'items': [{'path': {'d': 'M15.033 9.44a.647.647 0 0 1 0 1.12l-4.065 2.352a.645.645 0 0 1-.968-.56V7.648a.645.645 0 0 1 .967-.56z'}}, {'path': {'d': 'M7 21h10'}}, {'rect': {'width': '20', 'height': '14', 'x': '2', 'y': '3', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareCode(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-code'], 'items': [{'path': {'d': 'm10 9-3 3 3 3'}}, {'path': {'d': 'm14 15 3-3-3-3'}}, {'rect': {'x': '3', 'y': '3', 'width': '18', 'height': '18', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowUpDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-up-down'], 'items': [{'path': {'d': 'm21 16-4 4-4-4'}}, {'path': {'d': 'M17 20V4'}}, {'path': {'d': 'm3 8 4-4 4 4'}}, {'path': {'d': 'M7 4v16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def WavesArrowUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-waves-arrow-up'], 'items': [{'path': {'d': 'M12 2v8'}}, {'path': {'d': 'M2 15c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1'}}, {'path': {'d': 'M2 21c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1'}}, {'path': {'d': 'm8 6 4-4 4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Loader(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-loader'], 'items': [{'path': {'d': 'M12 2v4'}}, {'path': {'d': 'm16.2 7.8 2.9-2.9'}}, {'path': {'d': 'M18 12h4'}}, {'path': {'d': 'm16.2 16.2 2.9 2.9'}}, {'path': {'d': 'M12 18v4'}}, {'path': {'d': 'm4.9 19.1 2.9-2.9'}}, {'path': {'d': 'M2 12h4'}}, {'path': {'d': 'm4.9 4.9 2.9 2.9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareFunction(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-function'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2', 'ry': '2'}}, {'path': {'d': 'M9 17c2 0 2.8-1 2.8-2.8V10c0-2 1-3.3 3.2-3'}}, {'path': {'d': 'M9 11.2h5.7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleArrowOutUpLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-arrow-out-up-left'], 'items': [{'path': {'d': 'M2 8V2h6'}}, {'path': {'d': 'm2 2 10 10'}}, {'path': {'d': 'M12 2A10 10 0 1 1 2 12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitBranchMinus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-branch-minus'], 'items': [{'path': {'d': 'M15 6a9 9 0 0 0-9 9V3'}}, {'path': {'d': 'M21 18h-6'}}, {'circle': {'cx': '18', 'cy': '6', 'r': '3'}}, {'circle': {'cx': '6', 'cy': '18', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Chromium(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chromium'], 'items': [{'path': {'d': 'M10.88 21.94 15.46 14'}}, {'path': {'d': 'M21.17 8H12'}}, {'path': {'d': 'M3.95 6.06 8.54 14'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wand(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wand'], 'items': [{'path': {'d': 'M15 4V2'}}, {'path': {'d': 'M15 16v-2'}}, {'path': {'d': 'M8 9h2'}}, {'path': {'d': 'M20 9h2'}}, {'path': {'d': 'M17.8 11.8 19 13'}}, {'path': {'d': 'M15 9h.01'}}, {'path': {'d': 'M17.8 6.2 19 5'}}, {'path': {'d': 'm3 21 9-9'}}, {'path': {'d': 'M12.2 6.2 11 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareArrowOutDownRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-arrow-out-down-right'], 'items': [{'path': {'d': 'M21 11V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h6'}}, {'path': {'d': 'm21 21-9-9'}}, {'path': {'d': 'M21 15v6h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Handbag(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-handbag'], 'items': [{'path': {'d': 'M2.048 18.566A2 2 0 0 0 4 21h16a2 2 0 0 0 1.952-2.434l-2-9A2 2 0 0 0 18 8H6a2 2 0 0 0-1.952 1.566z'}}, {'path': {'d': 'M8 11V6a4 4 0 0 1 8 0v5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlaskConicalOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flask-conical-off'], 'items': [{'path': {'d': 'M10 2v2.343'}}, {'path': {'d': 'M14 2v6.343'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M20 20a2 2 0 0 1-2 2H6a2 2 0 0 1-1.755-2.96l5.227-9.563'}}, {'path': {'d': 'M6.453 15H15'}}, {'path': {'d': 'M8.5 2h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileOutput(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-output'], 'items': [{'path': {'d': 'M4.226 20.925A2 2 0 0 0 6 22h12a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v3.127'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'm5 11-3 3'}}, {'path': {'d': 'm5 17-3-3h10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Droplet(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-droplet'], 'items': [{'path': {'d': 'M12 22a7 7 0 0 0 7-7c0-2-1-3.9-3-5.5s-3.5-4-4-6.5c-.5 2.5-2 4.9-4 6.5C6 11.1 5 13 5 15a7 7 0 0 0 7 7z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Martini(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-martini'], 'items': [{'path': {'d': 'M8 22h8'}}, {'path': {'d': 'M12 11v11'}}, {'path': {'d': 'm19 3-7 8-7-8Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Coins(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-coins'], 'items': [{'circle': {'cx': '8', 'cy': '8', 'r': '6'}}, {'path': {'d': 'M18.09 10.37A6 6 0 1 1 10.34 18'}}, {'path': {'d': 'M7 6h1v4'}}, {'path': {'d': 'm16.71 13.88.7.71-2.82 2.82'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bubbles(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bubbles'], 'items': [{'path': {'d': 'M7.2 14.8a2 2 0 0 1 2 2'}}, {'circle': {'cx': '18.5', 'cy': '8.5', 'r': '3.5'}}, {'circle': {'cx': '7.5', 'cy': '16.5', 'r': '5.5'}}, {'circle': {'cx': '7.5', 'cy': '4.5', 'r': '2.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Gift(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-gift'], 'items': [{'rect': {'x': '3', 'y': '8', 'width': '18', 'height': '4', 'rx': '1'}}, {'path': {'d': 'M12 8v13'}}, {'path': {'d': 'M19 12v7a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2v-7'}}, {'path': {'d': 'M7.5 8a2.5 2.5 0 0 1 0-5A4.8 8 0 0 1 12 8a4.8 8 0 0 1 4.5-5 2.5 2.5 0 0 1 0 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HousePlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-house-plus'], 'items': [{'path': {'d': 'M12.35 21H5a2 2 0 0 1-2-2v-9a2 2 0 0 1 .71-1.53l7-6a2 2 0 0 1 2.58 0l7 6A2 2 0 0 1 21 10v2.35'}}, {'path': {'d': 'M14.8 12.4A1 1 0 0 0 14 12h-4a1 1 0 0 0-1 1v8'}}, {'path': {'d': 'M15 18h6'}}, {'path': {'d': 'M18 15v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Strikethrough(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-strikethrough'], 'items': [{'path': {'d': 'M16 4H9a3 3 0 0 0-2.83 4'}}, {'path': {'d': 'M14 12a4 4 0 0 1 0 8H6'}}, {'line': {'x1': '4', 'x2': '20', 'y1': '12', 'y2': '12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RefreshCw(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-refresh-cw'], 'items': [{'path': {'d': 'M3 12a9 9 0 0 1 9-9 9.75 9.75 0 0 1 6.74 2.74L21 8'}}, {'path': {'d': 'M21 3v5h-5'}}, {'path': {'d': 'M21 12a9 9 0 0 1-9 9 9.75 9.75 0 0 1-6.74-2.74L3 16'}}, {'path': {'d': 'M8 16H3v5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TableColumnsSplit(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-table-columns-split'], 'items': [{'path': {'d': 'M14 14v2'}}, {'path': {'d': 'M14 20v2'}}, {'path': {'d': 'M14 2v2'}}, {'path': {'d': 'M14 8v2'}}, {'path': {'d': 'M2 15h8'}}, {'path': {'d': 'M2 3h6a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H2'}}, {'path': {'d': 'M2 9h8'}}, {'path': {'d': 'M22 15h-4'}}, {'path': {'d': 'M22 3h-2a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h2'}}, {'path': {'d': 'M22 9h-4'}}, {'path': {'d': 'M5 3v18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChefHat(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chef-hat'], 'items': [{'path': {'d': 'M17 21a1 1 0 0 0 1-1v-5.35c0-.457.316-.844.727-1.041a4 4 0 0 0-2.134-7.589 5 5 0 0 0-9.186 0 4 4 0 0 0-2.134 7.588c.411.198.727.585.727 1.041V20a1 1 0 0 0 1 1Z'}}, {'path': {'d': 'M6 17h12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ReceiptJapaneseYen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-receipt-japanese-yen'], 'items': [{'path': {'d': 'M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z'}}, {'path': {'d': 'm12 10 3-3'}}, {'path': {'d': 'm9 7 3 3v7.5'}}, {'path': {'d': 'M9 11h6'}}, {'path': {'d': 'M9 15h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def StepForward(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-step-forward'], 'items': [{'path': {'d': 'M10.029 4.285A2 2 0 0 0 7 6v12a2 2 0 0 0 3.029 1.715l9.997-5.998a2 2 0 0 0 .003-3.432z'}}, {'path': {'d': 'M3 4v16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AudioWaveform(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-audio-waveform'], 'items': [{'path': {'d': 'M2 13a2 2 0 0 0 2-2V7a2 2 0 0 1 4 0v13a2 2 0 0 0 4 0V4a2 2 0 0 1 4 0v13a2 2 0 0 0 4 0v-4a2 2 0 0 1 2-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Projector(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-projector'], 'items': [{'path': {'d': 'M5 7 3 5'}}, {'path': {'d': 'M9 6V3'}}, {'path': {'d': 'm13 7 2-2'}}, {'circle': {'cx': '9', 'cy': '13', 'r': '3'}}, {'path': {'d': 'M11.83 12H20a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-4a2 2 0 0 1 2-2h2.17'}}, {'path': {'d': 'M16 16h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AudioLines(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-audio-lines'], 'items': [{'path': {'d': 'M2 10v3'}}, {'path': {'d': 'M6 6v11'}}, {'path': {'d': 'M10 3v18'}}, {'path': {'d': 'M14 8v7'}}, {'path': {'d': 'M18 5v13'}}, {'path': {'d': 'M22 10v3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bell(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bell'], 'items': [{'path': {'d': 'M10.268 21a2 2 0 0 0 3.464 0'}}, {'path': {'d': 'M3.262 15.326A1 1 0 0 0 4 17h16a1 1 0 0 0 .74-1.673C19.41 13.956 18 12.499 18 8A6 6 0 0 0 6 8c0 4.499-1.411 5.956-2.738 7.326'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TextAlignJustify(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-text-align-justify'], 'items': [{'path': {'d': 'M3 5h18'}}, {'path': {'d': 'M3 12h18'}}, {'path': {'d': 'M3 19h18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def NavigationOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-navigation-off'], 'items': [{'path': {'d': 'M8.43 8.43 3 11l8 2 2 8 2.57-5.43'}}, {'path': {'d': 'M17.39 11.73 22 2l-9.73 4.61'}}, {'line': {'x1': '2', 'x2': '22', 'y1': '2', 'y2': '22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartArea(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-area'], 'items': [{'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}, {'path': {'d': 'M7 11.207a.5.5 0 0 1 .146-.353l2-2a.5.5 0 0 1 .708 0l3.292 3.292a.5.5 0 0 0 .708 0l4.292-4.292a.5.5 0 0 1 .854.353V16a1 1 0 0 1-1 1H8a1 1 0 0 1-1-1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Music2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-music-2'], 'items': [{'circle': {'cx': '8', 'cy': '18', 'r': '4'}}, {'path': {'d': 'M12 18V2l7 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CaseUpper(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-case-upper'], 'items': [{'path': {'d': 'M15 11h4.5a1 1 0 0 1 0 5h-4a.5.5 0 0 1-.5-.5v-9a.5.5 0 0 1 .5-.5h3a1 1 0 0 1 0 5'}}, {'path': {'d': 'm2 16 4.039-9.69a.5.5 0 0 1 .923 0L11 16'}}, {'path': {'d': 'M3.304 13h6.392'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MessageSquareDot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-message-square-dot'], 'items': [{'path': {'d': 'M12.7 3H4a2 2 0 0 0-2 2v16.286a.71.71 0 0 0 1.212.502l2.202-2.202A2 2 0 0 1 6.828 19H20a2 2 0 0 0 2-2v-4.7'}}, {'circle': {'cx': '19', 'cy': '6', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TentTree(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tent-tree'], 'items': [{'circle': {'cx': '4', 'cy': '4', 'r': '2'}}, {'path': {'d': 'm14 5 3-3 3 3'}}, {'path': {'d': 'm14 10 3-3 3 3'}}, {'path': {'d': 'M17 14V2'}}, {'path': {'d': 'M17 14H7l-5 8h20Z'}}, {'path': {'d': 'M8 14v8'}}, {'path': {'d': 'm9 14 5 8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserPen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-pen'], 'items': [{'path': {'d': 'M11.5 15H7a4 4 0 0 0-4 4v2'}}, {'path': {'d': 'M21.378 16.626a1 1 0 0 0-3.004-3.004l-4.01 4.012a2 2 0 0 0-.506.854l-.837 2.87a.5.5 0 0 0 .62.62l2.87-.837a2 2 0 0 0 .854-.506z'}}, {'circle': {'cx': '10', 'cy': '7', 'r': '4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Framer(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-framer'], 'items': [{'path': {'d': 'M5 16V9h14V2H5l14 14h-7m-7 0 7 7v-7m-7 0h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Images(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-images'], 'items': [{'path': {'d': 'm22 11-1.296-1.296a2.4 2.4 0 0 0-3.408 0L11 16'}}, {'path': {'d': 'M4 8a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2'}}, {'circle': {'cx': '13', 'cy': '7', 'r': '1', 'fill': 'currentColor'}}, {'rect': {'x': '8', 'y': '2', 'width': '14', 'height': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Activity(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-activity'], 'items': [{'path': {'d': 'M22 12h-2.48a2 2 0 0 0-1.93 1.46l-2.35 8.36a.25.25 0 0 1-.48 0L9.24 2.18a.25.25 0 0 0-.48 0l-2.35 8.36A2 2 0 0 1 4.49 12H2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LoaderPinwheel(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-loader-pinwheel'], 'items': [{'path': {'d': 'M22 12a1 1 0 0 1-10 0 1 1 0 0 0-10 0'}}, {'path': {'d': 'M7 20.7a1 1 0 1 1 5-8.7 1 1 0 1 0 5-8.6'}}, {'path': {'d': 'M7 3.3a1 1 0 1 1 5 8.6 1 1 0 1 0 5 8.6'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield





import os
import xml.etree.ElementTree as ET
import keyword
import shutil

def to_pascal_case(s):
    pascal_cased = ''.join(word.capitalize() for word in s.replace('-', '_').split('_'))
    # If the pascal cased name is a keyword, append an underscore
    if keyword.iskeyword(pascal_cased):
        return pascal_cased + '_'
    return pascal_cased

def create_icon_library():
    icons_dir = 'resources/lucide/icons'
    
    package_root_dir = 'lucide'
    icons_output_dir = os.path.join(package_root_dir, 'icons')

    os.makedirs(icons_output_dir, exist_ok=True)

    # Clean the icons output directory before generating new files
    for f in os.listdir(icons_output_dir):
        file_path = os.path.join(icons_output_dir, f)
        if os.path.isfile(file_path):
            os.remove(file_path)
        elif os.path.isdir(file_path):
            shutil.rmtree(file_path)

    # Open both __init__.py files before the loop
    with open(os.path.join(package_root_dir, '__init__.py'), 'w') as f1, \
         open(os.path.join(icons_output_dir, '__init__.py'), 'w') as f_icons_init:
        
        f1.write("# Lucide Icons\n")
        f_icons_init.write("# Lucide Icons Subpackage\n")

        # Write base.py (this can be outside the f1, f_icons_init context if it doesn't need them)
        with open(os.path.join(icons_output_dir, 'base.py'), 'w') as f_base:
            f_base.write("""
import contextlib
from collections.abc import Generator
from tagflow import tag
from tagflow.tagflow import AttrValue


@contextlib.contextmanager
def IconBase(
    data: dict, **kwargs
) -> Generator[None]:
    defaults = {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round",
    }
    if "classes" in data:
        defaults["classes"] = data.get("classes")
    
    defaults.update(kwargs)

    with tag.svg(**defaults):        
        for item in data["items"]:
            for element_name, element_attrs in item.items():
                with tag(element_name, **element_attrs):
                    pass
    
    yield
""")

        for filename in os.listdir(icons_dir):
            if not filename.endswith('.svg'):
                continue

            icon_name = os.path.splitext(filename)[0]
            
            module_name = icon_name.replace('-', '_')
            if keyword.iskeyword(module_name):
                module_name += '_'

            class_name = to_pascal_case(icon_name)

            with open(os.path.join(icons_dir, filename), 'r') as f_svg:
                svg_content = f_svg.read()

            try:
                root = ET.fromstring(svg_content)
                items = []
                for child in root:
                    tag = child.tag.split('}')[-1]
                    items.append({tag: child.attrib})
                
                data = {
                    "classes": [f"lucide lucide-{icon_name}"],
                    "items": items
                }

                f1.write(f"from .icons.{module_name} import {class_name}\n")
                f_icons_init.write(f"from .{module_name} import {class_name}\n")

                with open(os.path.join(icons_output_dir, f"{module_name}.py"), 'w') as f_icon_module:
                    f_icon_module.write(f"""
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def {class_name}(**kwargs) -> Generator[None]:
    data = {data}
    with IconBase(data, **kwargs):
        pass
    yield
""")
            except ET.ParseError:
                print(f"Could not parse {filename}")


if __name__ == '__main__':
    create_icon_library()




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Navigation(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-navigation'], 'items': [{'polygon': {'points': '3 11 22 2 13 21 11 13 3 11'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowRightLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-right-left'], 'items': [{'path': {'d': 'm16 3 4 4-4 4'}}, {'path': {'d': 'M20 7H4'}}, {'path': {'d': 'm8 21-4-4 4-4'}}, {'path': {'d': 'M4 17h16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PiggyBank(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-piggy-bank'], 'items': [{'path': {'d': 'M11 17h3v2a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-3a3.16 3.16 0 0 0 2-2h1a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1h-1a5 5 0 0 0-2-4V3a4 4 0 0 0-3.2 1.6l-.3.4H11a6 6 0 0 0-6 6v1a5 5 0 0 0 2 4v3a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1z'}}, {'path': {'d': 'M16 10h.01'}}, {'path': {'d': 'M2 8v1a2 2 0 0 0 2 2h1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TableRowsSplit(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-table-rows-split'], 'items': [{'path': {'d': 'M14 10h2'}}, {'path': {'d': 'M15 22v-8'}}, {'path': {'d': 'M15 2v4'}}, {'path': {'d': 'M2 10h2'}}, {'path': {'d': 'M20 10h2'}}, {'path': {'d': 'M3 19h18'}}, {'path': {'d': 'M3 22v-6a2 2 135 0 1 2-2h14a2 2 45 0 1 2 2v6'}}, {'path': {'d': 'M3 2v2a2 2 45 0 0 2 2h14a2 2 135 0 0 2-2V2'}}, {'path': {'d': 'M8 10h2'}}, {'path': {'d': 'M9 22v-8'}}, {'path': {'d': 'M9 2v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DoorOpen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-door-open'], 'items': [{'path': {'d': 'M11 20H2'}}, {'path': {'d': 'M11 4.562v16.157a1 1 0 0 0 1.242.97L19 20V5.562a2 2 0 0 0-1.515-1.94l-4-1A2 2 0 0 0 11 4.561z'}}, {'path': {'d': 'M11 4H8a2 2 0 0 0-2 2v14'}}, {'path': {'d': 'M14 12h.01'}}, {'path': {'d': 'M22 20h-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleParkingOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-parking-off'], 'items': [{'path': {'d': 'M12.656 7H13a3 3 0 0 1 2.984 3.307'}}, {'path': {'d': 'M13 13H9'}}, {'path': {'d': 'M19.071 19.071A1 1 0 0 1 4.93 4.93'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M8.357 2.687a10 10 0 0 1 12.956 12.956'}}, {'path': {'d': 'M9 17V9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Router(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-router'], 'items': [{'rect': {'width': '20', 'height': '8', 'x': '2', 'y': '14', 'rx': '2'}}, {'path': {'d': 'M6.01 18H6'}}, {'path': {'d': 'M10.01 18H10'}}, {'path': {'d': 'M15 10v4'}}, {'path': {'d': 'M17.84 7.17a4 4 0 0 0-5.66 0'}}, {'path': {'d': 'M20.66 4.34a8 8 0 0 0-11.31 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Cross(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cross'], 'items': [{'path': {'d': 'M4 9a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h4a1 1 0 0 1 1 1v4a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2v-4a1 1 0 0 1 1-1h4a2 2 0 0 0 2-2v-2a2 2 0 0 0-2-2h-4a1 1 0 0 1-1-1V4a2 2 0 0 0-2-2h-2a2 2 0 0 0-2 2v4a1 1 0 0 1-1 1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileSpreadsheet(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-spreadsheet'], 'items': [{'path': {'d': 'M6 22a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.704.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2z'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M8 13h2'}}, {'path': {'d': 'M14 13h2'}}, {'path': {'d': 'M8 17h2'}}, {'path': {'d': 'M14 17h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HandMetal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hand-metal'], 'items': [{'path': {'d': 'M18 12.5V10a2 2 0 0 0-2-2a2 2 0 0 0-2 2v1.4'}}, {'path': {'d': 'M14 11V9a2 2 0 1 0-4 0v2'}}, {'path': {'d': 'M10 10.5V5a2 2 0 1 0-4 0v9'}}, {'path': {'d': 'm7 15-1.76-1.76a2 2 0 0 0-2.83 2.82l3.6 3.6C7.5 21.14 9.2 22 12 22h2a8 8 0 0 0 8-8V7a2 2 0 1 0-4 0v5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareTerminal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-terminal'], 'items': [{'path': {'d': 'm7 11 2-2-2-2'}}, {'path': {'d': 'M11 13h4'}}, {'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2', 'ry': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListIndentIncrease(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-indent-increase'], 'items': [{'path': {'d': 'M21 5H11'}}, {'path': {'d': 'M21 12H11'}}, {'path': {'d': 'M21 19H11'}}, {'path': {'d': 'm3 8 4 4-4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Angry(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-angry'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M16 16s-1.5-2-4-2-4 2-4 2'}}, {'path': {'d': 'M7.5 8 10 9'}}, {'path': {'d': 'm14 9 2.5-1'}}, {'path': {'d': 'M9 10h.01'}}, {'path': {'d': 'M15 10h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookOpenCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-open-check'], 'items': [{'path': {'d': 'M12 21V7'}}, {'path': {'d': 'm16 12 2 2 4-4'}}, {'path': {'d': 'M22 6V4a1 1 0 0 0-1-1h-5a4 4 0 0 0-4 4 4 4 0 0 0-4-4H3a1 1 0 0 0-1 1v13a1 1 0 0 0 1 1h6a3 3 0 0 1 3 3 3 3 0 0 1 3-3h6a1 1 0 0 0 1-1v-1.3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Feather(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-feather'], 'items': [{'path': {'d': 'M12.67 19a2 2 0 0 0 1.416-.588l6.154-6.172a6 6 0 0 0-8.49-8.49L5.586 9.914A2 2 0 0 0 5 11.328V18a1 1 0 0 0 1 1z'}}, {'path': {'d': 'M16 8 2 22'}}, {'path': {'d': 'M17.5 15H9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Repeat(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-repeat'], 'items': [{'path': {'d': 'm17 2 4 4-4 4'}}, {'path': {'d': 'M3 11v-1a4 4 0 0 1 4-4h14'}}, {'path': {'d': 'm7 22-4-4 4-4'}}, {'path': {'d': 'M21 13v1a4 4 0 0 1-4 4H3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HandGrab(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hand-grab'], 'items': [{'path': {'d': 'M18 11.5V9a2 2 0 0 0-2-2a2 2 0 0 0-2 2v1.4'}}, {'path': {'d': 'M14 10V8a2 2 0 0 0-2-2a2 2 0 0 0-2 2v2'}}, {'path': {'d': 'M10 9.9V9a2 2 0 0 0-2-2a2 2 0 0 0-2 2v5'}}, {'path': {'d': 'M6 14a2 2 0 0 0-2-2a2 2 0 0 0-2 2'}}, {'path': {'d': 'M18 11a2 2 0 1 1 4 0v3a8 8 0 0 1-8 8h-4a8 8 0 0 1-8-8 2 2 0 1 1 4 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Forklift(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-forklift'], 'items': [{'path': {'d': 'M12 12H5a2 2 0 0 0-2 2v5'}}, {'circle': {'cx': '13', 'cy': '19', 'r': '2'}}, {'circle': {'cx': '5', 'cy': '19', 'r': '2'}}, {'path': {'d': 'M8 19h3m5-17v17h6M6 12V7c0-1.1.9-2 2-2h3l5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Brackets(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-brackets'], 'items': [{'path': {'d': 'M16 3h3a1 1 0 0 1 1 1v16a1 1 0 0 1-1 1h-3'}}, {'path': {'d': 'M8 21H5a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Vote(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-vote'], 'items': [{'path': {'d': 'm9 12 2 2 4-4'}}, {'path': {'d': 'M5 7c0-1.1.9-2 2-2h10a2 2 0 0 1 2 2v12H5V7Z'}}, {'path': {'d': 'M22 19H2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveDownRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-down-right'], 'items': [{'path': {'d': 'M19 13V19H13'}}, {'path': {'d': 'M5 5L19 19'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def VideoOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-video-off'], 'items': [{'path': {'d': 'M10.66 6H14a2 2 0 0 1 2 2v2.5l5.248-3.062A.5.5 0 0 1 22 7.87v8.196'}}, {'path': {'d': 'M16 16a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h2'}}, {'path': {'d': 'm2 2 20 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PocketKnife(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pocket-knife'], 'items': [{'path': {'d': 'M3 2v1c0 1 2 1 2 2S3 6 3 7s2 1 2 2-2 1-2 2 2 1 2 2'}}, {'path': {'d': 'M18 6h.01'}}, {'path': {'d': 'M6 18h.01'}}, {'path': {'d': 'M20.83 8.83a4 4 0 0 0-5.66-5.66l-12 12a4 4 0 1 0 5.66 5.66Z'}}, {'path': {'d': 'M18 11.66V22a4 4 0 0 0 4-4V6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CornerDownLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-corner-down-left'], 'items': [{'path': {'d': 'M20 4v7a4 4 0 0 1-4 4H4'}}, {'path': {'d': 'm9 10-5 5 5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileHeadphone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-headphone'], 'items': [{'path': {'d': 'M4 6.835V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2h-.343'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M2 19a2 2 0 0 1 4 0v1a2 2 0 0 1-4 0v-4a6 6 0 0 1 12 0v4a2 2 0 0 1-4 0v-1a2 2 0 0 1 4 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Equal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-equal'], 'items': [{'line': {'x1': '5', 'x2': '19', 'y1': '9', 'y2': '9'}}, {'line': {'x1': '5', 'x2': '19', 'y1': '15', 'y2': '15'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Monitor(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor'], 'items': [{'rect': {'width': '20', 'height': '14', 'x': '2', 'y': '3', 'rx': '2'}}, {'line': {'x1': '8', 'x2': '16', 'y1': '21', 'y2': '21'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '17', 'y2': '21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Radius(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-radius'], 'items': [{'path': {'d': 'M20.34 17.52a10 10 0 1 0-2.82 2.82'}}, {'circle': {'cx': '19', 'cy': '19', 'r': '2'}}, {'path': {'d': 'm13.41 13.41 4.18 4.18'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Signature(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-signature'], 'items': [{'path': {'d': 'm21 17-2.156-1.868A.5.5 0 0 0 18 15.5v.5a1 1 0 0 1-1 1h-2a1 1 0 0 1-1-1c0-2.545-3.991-3.97-8.5-4a1 1 0 0 0 0 5c4.153 0 4.745-11.295 5.708-13.5a2.5 2.5 0 1 1 3.31 3.284'}}, {'path': {'d': 'M3 21h18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Apple(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-apple'], 'items': [{'path': {'d': 'M12 6.528V3a1 1 0 0 1 1-1h0'}}, {'path': {'d': 'M18.237 21A15 15 0 0 0 22 11a6 6 0 0 0-10-4.472A6 6 0 0 0 2 11a15.1 15.1 0 0 0 3.763 10 3 3 0 0 0 3.648.648 5.5 5.5 0 0 1 5.178 0A3 3 0 0 0 18.237 21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LampWallDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lamp-wall-down'], 'items': [{'path': {'d': 'M19.929 18.629A1 1 0 0 1 19 20H9a1 1 0 0 1-.928-1.371l2-5A1 1 0 0 1 11 13h6a1 1 0 0 1 .928.629z'}}, {'path': {'d': 'M6 3a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H5a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M8 6h4a2 2 0 0 1 2 2v5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bandage(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bandage'], 'items': [{'path': {'d': 'M10 10.01h.01'}}, {'path': {'d': 'M10 14.01h.01'}}, {'path': {'d': 'M14 10.01h.01'}}, {'path': {'d': 'M14 14.01h.01'}}, {'path': {'d': 'M18 6v11.5'}}, {'path': {'d': 'M6 6v12'}}, {'rect': {'x': '2', 'y': '6', 'width': '20', 'height': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RotateCcwKey(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rotate-ccw-key'], 'items': [{'path': {'d': 'm14.5 9.5 1 1'}}, {'path': {'d': 'm15.5 8.5-4 4'}}, {'path': {'d': 'M3 12a9 9 0 1 0 9-9 9.74 9.74 0 0 0-6.74 2.74L3 8'}}, {'path': {'d': 'M3 3v5h5'}}, {'circle': {'cx': '10', 'cy': '14', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Flashlight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flashlight'], 'items': [{'path': {'d': 'M18 6c0 2-2 2-2 4v10a2 2 0 0 1-2 2h-4a2 2 0 0 1-2-2V10c0-2-2-2-2-4V2h12z'}}, {'line': {'x1': '6', 'x2': '18', 'y1': '6', 'y2': '6'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '12', 'y2': '12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleArrowOutDownLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-arrow-out-down-left'], 'items': [{'path': {'d': 'M2 12a10 10 0 1 1 10 10'}}, {'path': {'d': 'm2 22 10-10'}}, {'path': {'d': 'M8 22H2v-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderGit2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-git-2'], 'items': [{'path': {'d': 'M18 19a5 5 0 0 1-5-5v8'}}, {'path': {'d': 'M9 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v5'}}, {'circle': {'cx': '13', 'cy': '12', 'r': '2'}}, {'circle': {'cx': '20', 'cy': '19', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pentagon(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pentagon'], 'items': [{'path': {'d': 'M10.83 2.38a2 2 0 0 1 2.34 0l8 5.74a2 2 0 0 1 .73 2.25l-3.04 9.26a2 2 0 0 1-1.9 1.37H7.04a2 2 0 0 1-1.9-1.37L2.1 10.37a2 2 0 0 1 .73-2.25z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CornerLeftUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-corner-left-up'], 'items': [{'path': {'d': 'M14 9 9 4 4 9'}}, {'path': {'d': 'M20 20h-7a4 4 0 0 1-4-4V4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BadgeIndianRupee(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-badge-indian-rupee'], 'items': [{'path': {'d': 'M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z'}}, {'path': {'d': 'M8 8h8'}}, {'path': {'d': 'M8 12h8'}}, {'path': {'d': 'm13 17-5-1h1a4 4 0 0 0 0-8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Frame(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-frame'], 'items': [{'line': {'x1': '22', 'x2': '2', 'y1': '6', 'y2': '6'}}, {'line': {'x1': '22', 'x2': '2', 'y1': '18', 'y2': '18'}}, {'line': {'x1': '6', 'x2': '6', 'y1': '2', 'y2': '22'}}, {'line': {'x1': '18', 'x2': '18', 'y1': '2', 'y2': '22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Youtube(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-youtube'], 'items': [{'path': {'d': 'M2.5 17a24.12 24.12 0 0 1 0-10 2 2 0 0 1 1.4-1.4 49.56 49.56 0 0 1 16.2 0A2 2 0 0 1 21.5 7a24.12 24.12 0 0 1 0 10 2 2 0 0 1-1.4 1.4 49.55 49.55 0 0 1-16.2 0A2 2 0 0 1 2.5 17'}}, {'path': {'d': 'm10 15 5-3-5-3z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bluetooth(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bluetooth'], 'items': [{'path': {'d': 'm7 7 10 10-5 5V2l5 5L7 17'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SaveAll(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-save-all'], 'items': [{'path': {'d': 'M10 2v3a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M18 18v-6a1 1 0 0 0-1-1h-6a1 1 0 0 0-1 1v6'}}, {'path': {'d': 'M18 22H4a2 2 0 0 1-2-2V6'}}, {'path': {'d': 'M8 18a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9.172a2 2 0 0 1 1.414.586l2.828 2.828A2 2 0 0 1 22 6.828V16a2 2 0 0 1-2.01 2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChevronsDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chevrons-down'], 'items': [{'path': {'d': 'm7 6 5 5 5-5'}}, {'path': {'d': 'm7 13 5 5 5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ImageUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-image-up'], 'items': [{'path': {'d': 'M10.3 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v10l-3.1-3.1a2 2 0 0 0-2.814.014L6 21'}}, {'path': {'d': 'm14 19.5 3-3 3 3'}}, {'path': {'d': 'M17 22v-5.5'}}, {'circle': {'cx': '9', 'cy': '9', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BusFront(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bus-front'], 'items': [{'path': {'d': 'M4 6 2 7'}}, {'path': {'d': 'M10 6h4'}}, {'path': {'d': 'm22 7-2-1'}}, {'rect': {'width': '16', 'height': '16', 'x': '4', 'y': '3', 'rx': '2'}}, {'path': {'d': 'M4 11h16'}}, {'path': {'d': 'M8 15h.01'}}, {'path': {'d': 'M16 15h.01'}}, {'path': {'d': 'M6 19v2'}}, {'path': {'d': 'M18 21v-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LogIn(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-log-in'], 'items': [{'path': {'d': 'm10 17 5-5-5-5'}}, {'path': {'d': 'M15 12H3'}}, {'path': {'d': 'M15 3h4a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MousePointer2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mouse-pointer-2'], 'items': [{'path': {'d': 'M4.037 4.688a.495.495 0 0 1 .651-.651l16 6.5a.5.5 0 0 1-.063.947l-6.124 1.58a2 2 0 0 0-1.438 1.435l-1.579 6.126a.5.5 0 0 1-.947.063z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListTree(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-tree'], 'items': [{'path': {'d': 'M8 5h13'}}, {'path': {'d': 'M13 12h8'}}, {'path': {'d': 'M13 19h8'}}, {'path': {'d': 'M3 10a2 2 0 0 0 2 2h3'}}, {'path': {'d': 'M3 5v12a2 2 0 0 0 2 2h3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TriangleRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-triangle-right'], 'items': [{'path': {'d': 'M22 18a2 2 0 0 1-2 2H3c-1.1 0-1.3-.6-.4-1.3L20.4 4.3c.9-.7 1.6-.4 1.6.7Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClockPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clock-plus'], 'items': [{'path': {'d': 'M12 6v6l3.644 1.822'}}, {'path': {'d': 'M16 19h6'}}, {'path': {'d': 'M19 16v6'}}, {'path': {'d': 'M21.92 13.267a10 10 0 1 0-8.653 8.653'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Beaker(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-beaker'], 'items': [{'path': {'d': 'M4.5 3h15'}}, {'path': {'d': 'M6 3v16a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V3'}}, {'path': {'d': 'M6 14h12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Workflow(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-workflow'], 'items': [{'rect': {'width': '8', 'height': '8', 'x': '3', 'y': '3', 'rx': '2'}}, {'path': {'d': 'M7 11v4a2 2 0 0 0 2 2h4'}}, {'rect': {'width': '8', 'height': '8', 'x': '13', 'y': '13', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Heading5(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-heading-5'], 'items': [{'path': {'d': 'M4 12h8'}}, {'path': {'d': 'M4 18V6'}}, {'path': {'d': 'M12 18V6'}}, {'path': {'d': 'M17 13v-3h4'}}, {'path': {'d': 'M17 17.7c.4.2.8.3 1.3.3 1.5 0 2.7-1.1 2.7-2.5S19.8 13 18.3 13H17'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveDiagonal2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-diagonal-2'], 'items': [{'path': {'d': 'M19 13v6h-6'}}, {'path': {'d': 'M5 11V5h6'}}, {'path': {'d': 'm5 5 14 14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def IndianRupee(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-indian-rupee'], 'items': [{'path': {'d': 'M6 3h12'}}, {'path': {'d': 'M6 8h12'}}, {'path': {'d': 'm6 13 8.5 8'}}, {'path': {'d': 'M6 13h3'}}, {'path': {'d': 'M9 13c6.667 0 6.667-10 0-10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Unlink2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-unlink-2'], 'items': [{'path': {'d': 'M15 7h2a5 5 0 0 1 0 10h-2m-6 0H7A5 5 0 0 1 7 7h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BluetoothOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bluetooth-off'], 'items': [{'path': {'d': 'm17 17-5 5V12l-5 5'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M14.5 9.5 17 7l-5-5v4.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileHeart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-heart'], 'items': [{'path': {'d': 'M13 22h5a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v7'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M3.62 18.8A2.25 2.25 0 1 1 7 15.836a2.25 2.25 0 1 1 3.38 2.966l-2.626 2.856a1 1 0 0 1-1.507 0z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def IceCreamCone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ice-cream-cone'], 'items': [{'path': {'d': 'm7 11 4.08 10.35a1 1 0 0 0 1.84 0L17 11'}}, {'path': {'d': 'M17 7A5 5 0 0 0 7 7'}}, {'path': {'d': 'M17 7a2 2 0 0 1 0 4H7a2 2 0 0 1 0-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Heading3(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-heading-3'], 'items': [{'path': {'d': 'M4 12h8'}}, {'path': {'d': 'M4 18V6'}}, {'path': {'d': 'M12 18V6'}}, {'path': {'d': 'M17.5 10.5c1.7-1 3.5 0 3.5 1.5a2 2 0 0 1-2 2'}}, {'path': {'d': 'M17 17.5c2 1.5 4 .3 4-1.5a2 2 0 0 0-2-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LayoutGrid(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-layout-grid'], 'items': [{'rect': {'width': '7', 'height': '7', 'x': '3', 'y': '3', 'rx': '1'}}, {'rect': {'width': '7', 'height': '7', 'x': '14', 'y': '3', 'rx': '1'}}, {'rect': {'width': '7', 'height': '7', 'x': '14', 'y': '14', 'rx': '1'}}, {'rect': {'width': '7', 'height': '7', 'x': '3', 'y': '14', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Copy(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-copy'], 'items': [{'rect': {'width': '14', 'height': '14', 'x': '8', 'y': '8', 'rx': '2', 'ry': '2'}}, {'path': {'d': 'M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lamp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lamp'], 'items': [{'path': {'d': 'M12 12v6'}}, {'path': {'d': 'M4.077 10.615A1 1 0 0 0 5 12h14a1 1 0 0 0 .923-1.385l-3.077-7.384A2 2 0 0 0 15 2H9a2 2 0 0 0-1.846 1.23Z'}}, {'path': {'d': 'M8 20a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1H9a1 1 0 0 1-1-1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquarePower(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-power'], 'items': [{'path': {'d': 'M12 7v4'}}, {'path': {'d': 'M7.998 9.003a5 5 0 1 0 8-.005'}}, {'rect': {'x': '3', 'y': '3', 'width': '18', 'height': '18', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wrench(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wrench'], 'items': [{'path': {'d': 'M14.7 6.3a1 1 0 0 0 0 1.4l1.6 1.6a1 1 0 0 0 1.4 0l3.106-3.105c.32-.322.863-.22.983.218a6 6 0 0 1-8.259 7.057l-7.91 7.91a1 1 0 0 1-2.999-3l7.91-7.91a6 6 0 0 1 7.057-8.259c.438.12.54.662.219.984z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CookingPot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cooking-pot'], 'items': [{'path': {'d': 'M2 12h20'}}, {'path': {'d': 'M20 12v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-8'}}, {'path': {'d': 'm4 8 16-4'}}, {'path': {'d': 'm8.86 6.78-.45-1.81a2 2 0 0 1 1.45-2.43l1.94-.48a2 2 0 0 1 2.43 1.46l.45 1.8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LampFloor(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lamp-floor'], 'items': [{'path': {'d': 'M12 10v12'}}, {'path': {'d': 'M17.929 7.629A1 1 0 0 1 17 9H7a1 1 0 0 1-.928-1.371l2-5A1 1 0 0 1 9 2h6a1 1 0 0 1 .928.629z'}}, {'path': {'d': 'M9 22h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sigma(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sigma'], 'items': [{'path': {'d': 'M18 7V5a1 1 0 0 0-1-1H6.5a.5.5 0 0 0-.4.8l4.5 6a2 2 0 0 1 0 2.4l-4.5 6a.5.5 0 0 0 .4.8H17a1 1 0 0 0 1-1v-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def VenetianMask(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-venetian-mask'], 'items': [{'path': {'d': 'M18 11c-1.5 0-2.5.5-3 2'}}, {'path': {'d': 'M4 6a2 2 0 0 0-2 2v4a5 5 0 0 0 5 5 8 8 0 0 1 5 2 8 8 0 0 1 5-2 5 5 0 0 0 5-5V8a2 2 0 0 0-2-2h-3a8 8 0 0 0-5 2 8 8 0 0 0-5-2z'}}, {'path': {'d': 'M6 11c1.5 0 2.5.5 3 2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlarmClockPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-alarm-clock-plus'], 'items': [{'circle': {'cx': '12', 'cy': '13', 'r': '8'}}, {'path': {'d': 'M5 3 2 6'}}, {'path': {'d': 'm22 6-3-3'}}, {'path': {'d': 'M6.38 18.7 4 21'}}, {'path': {'d': 'M17.64 18.67 20 21'}}, {'path': {'d': 'M12 10v6'}}, {'path': {'d': 'M9 13h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Microscope(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-microscope'], 'items': [{'path': {'d': 'M6 18h8'}}, {'path': {'d': 'M3 22h18'}}, {'path': {'d': 'M14 22a7 7 0 1 0 0-14h-1'}}, {'path': {'d': 'M9 14h2'}}, {'path': {'d': 'M9 12a2 2 0 0 1-2-2V6h6v4a2 2 0 0 1-2 2Z'}}, {'path': {'d': 'M12 6V3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BatteryFull(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-battery-full'], 'items': [{'path': {'d': 'M10 10v4'}}, {'path': {'d': 'M14 10v4'}}, {'path': {'d': 'M22 14v-4'}}, {'path': {'d': 'M6 10v4'}}, {'rect': {'x': '2', 'y': '6', 'width': '16', 'height': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ThumbsDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-thumbs-down'], 'items': [{'path': {'d': 'M17 14V2'}}, {'path': {'d': 'M9 18.12 10 14H4.17a2 2 0 0 1-1.92-2.56l2.33-8A2 2 0 0 1 6.5 2H20a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.76a2 2 0 0 0-1.79 1.11L12 22a3.13 3.13 0 0 1-3-3.88Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UnfoldHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-unfold-horizontal'], 'items': [{'path': {'d': 'M16 12h6'}}, {'path': {'d': 'M8 12H2'}}, {'path': {'d': 'M12 2v2'}}, {'path': {'d': 'M12 8v2'}}, {'path': {'d': 'M12 14v2'}}, {'path': {'d': 'M12 20v2'}}, {'path': {'d': 'm19 15 3-3-3-3'}}, {'path': {'d': 'm5 9-3 3 3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Backpack(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-backpack'], 'items': [{'path': {'d': 'M4 10a4 4 0 0 1 4-4h8a4 4 0 0 1 4 4v10a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2z'}}, {'path': {'d': 'M8 10h8'}}, {'path': {'d': 'M8 18h8'}}, {'path': {'d': 'M8 22v-6a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v6'}}, {'path': {'d': 'M9 6V4a2 2 0 0 1 2-2h2a2 2 0 0 1 2 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Cookie(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cookie'], 'items': [{'path': {'d': 'M12 2a10 10 0 1 0 10 10 4 4 0 0 1-5-5 4 4 0 0 1-5-5'}}, {'path': {'d': 'M8.5 8.5v.01'}}, {'path': {'d': 'M16 15.5v.01'}}, {'path': {'d': 'M12 12v.01'}}, {'path': {'d': 'M11 17v.01'}}, {'path': {'d': 'M7 14v.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Grid2x2Plus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-grid-2x2-plus'], 'items': [{'path': {'d': 'M12 3v17a1 1 0 0 1-1 1H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v6a1 1 0 0 1-1 1H3'}}, {'path': {'d': 'M16 19h6'}}, {'path': {'d': 'M19 22v-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DoorClosed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-door-closed'], 'items': [{'path': {'d': 'M10 12h.01'}}, {'path': {'d': 'M18 20V6a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v14'}}, {'path': {'d': 'M2 20h20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PoundSterling(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pound-sterling'], 'items': [{'path': {'d': 'M18 7c0-5.333-8-5.333-8 0'}}, {'path': {'d': 'M10 7v14'}}, {'path': {'d': 'M6 21h12'}}, {'path': {'d': 'M6 13h10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
